*-----------------------------------------------------------------------
*     SWPACK
*-----------------------------------------------------------------------
      SUBROUTINE SWDOPN

	 USE GTKPACK
      USE ZMPACK
      USE PSPACK
      USE SERVICE

      INTEGER   IMAGE(*)
      REAL      WPX(*), WPY(*)
      LOGICAL   LFCATR, LWDATR, LCLATR, LTNATR, LIMATR, LPTATR
      LOGICAL   LFCMOD, LCOLOR, LSEP, LFGBG
      CHARACTER COBJ*(*), COMM*(*), CFILE*(*)

      LOGICAL   LWAIT, LWAIT0, LWAIT1, LKEY, LDUMP, LALT
      CHARACTER CMSG*80, CLRMAP*80, CBTMAP*80, COUT*80,CPRN*80,CTTL*80
      CHARACTER CMAP*80

*必要かはわからないが追加

      LOGICAL   LWND
      CHARACTER CIMGFMT*8

      CHARACTER*20 OSV
      INTEGER MAJOR,MINOR

      SAVE

*     / OPEN ( AND ACTIVATE ) WORKSTATION /

      CALL SGIGET('IWS', JWS)
      CALL SWIGET('IWS', IWS)

      CMSG='GRPH1 : STARTED / IWS = ##.'
      CALL CHNGI(CMSG,'##',JWS,'(I2)')
      CALL MSGDMP('M','SWDOPN',CMSG)

*     / DEVICE DEPENDENT PARAMETERS /

      IF (IWS.EQ.1 .OR. IWS.EQ.2) THEN

        CALL SWIGET('IWIDTH ', IWIDTH)
        CALL SWIGET('IHEIGHT', IHEIGH)
        CALL SWIGET('ICLRMAP', ICLRMP)
        CALL SWLGET('LFGBG  ', LFGBG )
        CALL SWIGET('IPOSX  ', IPOSX )
        CALL SWIGET('IPOSY  ', IPOSY )
        CALL SWLGET('LWAIT  ', LWAIT )
        CALL SWLGET('LWAIT0 ', LWAIT0)
        CALL SWLGET('LWAIT1 ', LWAIT1)
        CALL SWLGET('LKEY   ', LKEY  )
        CALL SWLGET('LALT   ', LALT  )
        CALL SWLGET('LDUMP  ', LDUMP )
        CALL SWQFNM('BITM08', CBTMAP)

        CALL SWCMLL
        CALL SWQCMF(ICLRMP,CMAP)
        CALL SWCSET('CLRMAP',CMAP)

        IF(IWS.EQ.2) THEN
          IFACT = 4
          LWAIT0 = .FALSE.
          LALT   = .FALSE.
          IWIDTH = IWIDTH*IFACT
          IHEIGH = IHEIGH*IFACT
          CALL SWISET('IWIDTH ', IWIDTH)
          CALL SWISET('IHEIGHT', IHEIGH)

          CALL OSVERS(OSV,MAJOR,MINOR)
          IF(OSV.EQ.'WINDOWS_NT' .OR. OSV.EQ.'WINDOWS_2000') THEN
            CALL SWQFNM('BITM32', CBTMAP)
          END IF
        END IF

        IF (CBTMAP.EQ.' ') THEN
          CALL MSGDMP('E','SWDOPN','BITMAP FILE DOES NOT EXISIT.')
        END IF

        CALL SWCGET('FNAME  ', COUT  )

        IF (COUT.EQ.' ' .OR. COUT.EQ.'*') CALL OSGARG(0, COUT)
        IF (COUT.EQ.' ') THEN
          COUT = 'DCL'
          CALL CLOWER(COUT)
        END IF

        CALL SWQFNM('CLRMAP ', CLRMAP)
        IF (CLRMAP.EQ.' ') THEN
          CALL MSGDMP('E','SWDOPN','COLORMAP FILE DOES NOT EXISIT.')
        END IF
     
        CALL ZMDOPN(IWIDTH, IHEIGH, IPOSX, IPOSY,
     #              LWAIT0, LALT,   LDUMP, CLRMAP, CBTMAP, COUT, IWS)

        IF(IWS.EQ.2) CALL  ZMSTAT()

      ELSEIF( IWS.EQ.3) THEN
        CALL SWIGET('IWIDTH', IWIDTH)
        CALL SWIGET('IHEIGHT', IHEIGH)
        CALL SWLGET('LCOLOR' , LCOLOR)
        CALL SWLGET('LSEP'   , LSEP)
        CALL SWIGET('ICLRMAP', ICLRMP)
        CALL SWCGET('CPRN'   , CPRN)
        CALL SWCGET('TITLE'  , CTTL)
        CALL SWCGET('FNAME  ', COUT  )
        CALL SWCMLL
        CALL SWQCMF(ICLRMP,CMAP)
        CALL SWCSET('CLRMAP',CMAP)

        IF (COUT.EQ.' ' .OR. COUT.EQ.'*') CALL OSGARG(0, COUT)
        IF (COUT.EQ.' ') THEN
          COUT = 'DCL'
          CALL CLOWER(COUT)
        END IF

        CALL SWQFNM('CLRMAP ', CLRMAP)
        IF (CLRMAP.EQ.' ') THEN
          CALL MSGDMP('E','SWDOPN','COLORMAP FILE DOES NOT EXISIT.')
        END IF

        CALL Z1DOPN (iwidth, iheigh, lcolor, lsep, .false.,
     &          clrmap, cout, CTTL, CPRN)
      ELSEIF( IWS.EQ.4) THEN

        CALL SWIGET('IWIDTH ', IWIDTH)
        CALL SWIGET('IHEIGHT', IHEIGH)
        CALL SWIGET('ICLRMAP', ICLRMP)
        CALL SWLGET('LFGBG  ', LFGBG )
        CALL SWCGET('FNAME  ', COUT  )
        CALL SWCGET('TITLE  ', CTTL  )

        CALL SWCMLL
        CALL SWQFNM('CLRMAP ', CLRMAP)
*        CALL GLCGET('DSPATH',  DSPATH)
*        IF (CLRMAP.EQ.(DSPATH(1:LENC(DSPATH))//'colormap.x11')) THEN
          CALL SWQCMF(ICLRMP,CMAP)
          CALL SWCSET('CLRMAP ',CMAP)
*        END IF

        CALL SWQFNM('CLRMAP ', CLRMAP)
        IF (CLRMAP.EQ.' ') THEN
          CALL MSGDMP('E','SWDOPN','COLORMAP FILE DOES NOT EXIST.')
        END IF

        IF (COUT.EQ.' ' .OR. COUT.EQ.'*') CALL OSGARG(0, COUT)
        IF (COUT.EQ.' ') THEN
          COUT = 'DCL'
          CALL CLOWER(COUT)
        END IF

*        IF (CTTL.EQ.' ' .OR. CTTL.EQ.'*') CALL DCLVNM(CTTL)



        CALL SWIGET('IPOSX  ', IPOSX )
        CALL SWIGET('IPOSY  ', IPOSY )
        CALL SWLGET('LWAIT  ', LWAIT )
        CALL SWLGET('LWAIT0 ', LWAIT0)
        CALL SWLGET('LWAIT1 ', LWAIT1)
        CALL SWLGET('LALT   ', LALT  )
        CALL SWLGET('LKEY   ', LKEY  )
        CALL SWLGET('LDUMP  ', LDUMP )

*        CALL SWQFNM('BITMAP ', CBTMAP)
        CALL SWQFNM('BITM08', CBTMAP)
        IF (CBTMAP.EQ.' ') THEN
          CALL MSGDMP('E','SWDOPN','BITMAP FILE DOES NOT EXIST.')
        END IF

        CALL SWLGET('LWND   ', LWND  )

        CALL SWCGET('CIMGFMT ', CIMGFMT)
        CALL SWRGET('RIMGCMP ', RIMGCMP)

        CALL ZGDOPN(IWIDTH, IHEIGH, IPOSX, IPOSY,
     +       LWAIT, LWAIT0, LWAIT1, LALT, LKEY, LDUMP, LWND, LFGBG,
     +       CIMGFMT, RIMGCMP,CLRMAP, CBTMAP, COUT, CTTL)

      END IF
***
      CALL SGCLST(clrmap)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWSCLR(CFILE)
        CALL SWQFNM(CFILE, CLRMAP)
        IF (CLRMAP.EQ.' ') THEN

          CALL MSGDMP('E','SWSCLR','COLORMAP FILE DOES NOT EXISIT.')

        END IF
        CALL ZMCLINI(CLRMAP)
      RETURN
*-----------------------------------------------------------------------
      ENTRY SWDCLS

*     / ( DEACTIVATE AND ) CLOSE WORKSTATION /

      IF (IWS.EQ.1) THEN
        CALL SWLGET('LWAIT  ', LWAIT )
        CALL SWLGET('LWAIT1 ', LWAIT1)
        CALL ZMDCLS(.NOT.LWAIT .AND. LWAIT1)
      ELSE IF (IWS.EQ.2) THEN
        CALL ZMDCLS(.FALSE.)
      ELSE IF (IWS.EQ.3) THEN
        CALL Z1DCLS
      ENDIF
      IF (IWS.EQ.4) CALL ZGDCLS


      CMSG='GRPH1 : TERMINATED.'
      CALL MSGDMP('M','SWDCLS',CMSG)

*      LOPEN = .FALSE.

      RETURN
*-----------------------------------------------------------------------
*     PAGE
*-----------------------------------------------------------------------
      ENTRY SWPOPN

*     / OPEN PAGE ( OR SCREEN ) /

      IF (IWS.EQ.1 .OR. IWS.EQ.2) CALL ZMPOPN
      IF (IWS.EQ.3) CALL Z1POPN
      IF (IWS.EQ.4) CALL ZGPOPN

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWPCLS

*     / CLOSE PAGE ( OR SCREEN ) /


      NPAGE=NPAGE+1
      CMSG='GRPH1 : PAGE = ### COMPLETED.'
      CALL CHNGI(CMSG,'###',NPAGE,'(I3)')
      CALL MSGDMP('M','SWPCLS',CMSG)

      CALL SWLGET('LWAIT  ', LWAIT )
      CALL SWLGET('LDUMP  ', LDUMP )
      IF (IWS.EQ.1) CALL ZMPCLS (LWAIT, LDUMP)
      IF (IWS.EQ.2) CALL ZMPCLS (.FALSE., .FALSE.)
      IF (IWS.EQ.3) CALL Z1PCLS
      IF (IWS.EQ.4) CALL ZGPCLS

      RETURN
*-----------------------------------------------------------------------
*     OBJECT
*-----------------------------------------------------------------------
      ENTRY SWOOPN(COBJ, COMM)

*     / OPEN OBJECT /
      IF (IWS.EQ.1) CALL ZMOOPN(COBJ, COMM)
      IF (IWS.EQ.2) CALL ZMOOPN(COBJ, COMM)
      IF (IWS.EQ.3) CALL Z1OOPN(COBJ, COMM, LEN(COBJ), LEN(COMM))
      IF (IWS.EQ.4) CALL ZGOOPN(COBJ, COMM)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWOCLS(COBJ)

*     / CLOSE OBJECT /
      IF (IWS.EQ.1) CALL ZMOCLS(COBJ)
      IF (IWS.EQ.2) CALL ZMOCLS(COBJ)
      IF (IWS.EQ.3) CALL Z1OCLS(COBJ, LEN(COBJ))
      IF (IWS.EQ.4) CALL ZGOCLS(COBJ)

      RETURN
*-----------------------------------------------------------------------
*     FULL COLOR (2000/02/07 NEW)
*-----------------------------------------------------------------------
      ENTRY SWQFCC(LFCATR)

*     / INQUIRE FULL COLOR CAPABILITY /

      IF (IWS.EQ.1) CALL ZMQFCC(LFCATR)
      IF (IWS.EQ.2) CALL ZMQFCC(LFCATR)
*      IF (IWS.EQ.3) CALL Z1QFCC(LFCATR)
      IF (IWS.EQ.3) LFCATR = .TRUE.
      IF (IWS.EQ.4) LFCATR = .TRUE.

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWSFCM(LFCMOD)

*     / SET FULL COLOR MODE /

      IF (IWS.EQ.1) CALL ZMSFCM(LFCMOD)
      IF (IWS.EQ.2) CALL ZMSFCM(LFCMOD)
      IF (IWS.EQ.3) CALL Z1SFCM(LFCMOD)
      IF (IWS.EQ.4) CALL ZGSFCM(LFCMOD)

      RETURN
*-----------------------------------------------------------------------
*     LINE
*-----------------------------------------------------------------------
      ENTRY SWQWDC(LWDATR)

*     / INQUIRE LINE WIDTH CAPABILITY /

      IF (IWS.EQ.1) CALL ZMQWDC(LWDATR)
      IF (IWS.EQ.2) CALL ZMQWDC(LWDATR)
      IF (IWS.EQ.3) CALL Z1QWDC(LWDATR)
      IF (IWS.EQ.4) CALL ZGQWDC(LWDATR)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWQCLC(LCLATR)

*     / INQUIRE LINE COLOR CAPABILITY /

      IF (IWS.EQ.1) CALL ZMQCLC(LCLATR)
      IF (IWS.EQ.2) CALL ZMQCLC(LCLATR)
      IF (IWS.EQ.3) CALL Z1QCLC(LCLATR)
      IF (IWS.EQ.4) CALL ZGQCLC(LCLATR)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWSWDI(IWDIDX)

*     / SET LINE WIDTH INDEX /

      IF (IWS.EQ.1) CALL ZMSWDI(IWDIDX)
      IF (IWS.EQ.2) CALL ZMSWDI(IWDIDX)
      IF (IWS.EQ.3) CALL Z1SWDI(IWDIDX)
      IF (IWS.EQ.4) CALL ZGSWDI(IWDIDX)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWSCLI(ICLIDX,LFCATR)

*     / SET LINE COLOR INDEX /
      IF(.NOT.LFCATR) THEN

      IF (IWS.EQ.1) CALL ZMSCLI(ICLIDX)
      IF (IWS.EQ.2) CALL ZMSCLI(ICLIDX)
      IF (IWS.EQ.3) CALL Z1SCLI(ICLIDX)
      IF (IWS.EQ.4) CALL ZGSCLI(ICLIDX)

      ELSE

      CALL SGQCL(ICLIDX,NR,NB,NG)
      CALL UIFPAC(NR,NG,NB,NCOLOR)

      IF (IWS.EQ.1) CALL ZMSLCL(NCOLOR)
      IF (IWS.EQ.2) CALL ZMSLCL(NCOLOR)
      IF (IWS.EQ.3) CALL Z1SLCL(NCOLOR)
      IF (IWS.EQ.4) CALL ZGSLCL(NCOLOR)

      ENDIF

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWSLCL(ICOLOR)

*     / SET LINE COLOR IN 24BIT RGB /

      IF (IWS.EQ.1) CALL ZMSLCL(ICOLOR)
      IF (IWS.EQ.2) CALL ZMSLCL(ICOLOR)
      IF (IWS.EQ.3) CALL Z1SLCL(ICOLOR)
      IF (IWS.EQ.4) CALL ZGSLCL(ICOLOR)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWGOPN

*     / OPEN GRAPHIC SEGMENT /

      IF (IWS.EQ.1) CALL ZMGOPN
      IF (IWS.EQ.2) CALL ZMGOPN
      IF (IWS.EQ.3) CALL Z1GOPN
      IF (IWS.EQ.4) CALL ZGGOPN

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWGMOV(WX,WY)

*     / PEN-UP MOVE /

      IF (IWS.EQ.1) CALL ZMGMOV(WX,WY)
      IF (IWS.EQ.2) CALL ZMGMOV(WX,WY)
      IF (IWS.EQ.3) CALL Z1GMOV(WX,WY)
      IF (IWS.EQ.4) CALL ZGGMOV(WX,WY)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWGPLT(WX,WY)

*     / PEN-DOWN MOVE /

      IF (IWS.EQ.1) CALL ZMGPLT(WX,WY)
      IF (IWS.EQ.2) CALL ZMGPLT(WX,WY)
      IF (IWS.EQ.3) CALL Z1GPLT(WX,WY)
      IF (IWS.EQ.4) CALL ZGGPLT(WX,WY)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWGCLS

*     / CLOSE GRAPHIC SEGMENT /
      IF (IWS.EQ.1) CALL ZMGCLS
      IF (IWS.EQ.2) CALL ZMGCLS
      IF (IWS.EQ.3) CALL Z1GCLS
      IF (IWS.EQ.4) CALL ZGGCLS

      RETURN
*-----------------------------------------------------------------------
*     TONE
*-----------------------------------------------------------------------
      ENTRY SWQTNC(LTNATR)

*     / INQUIRE HARD FILL CAPABILITY /

      IF (IWS.EQ.1) CALL ZMQTNC(LTNATR)
      IF (IWS.EQ.2) CALL ZMQTNC(LTNATR)
      IF (IWS.EQ.3) CALL Z1QTNC(LTNATR)
      IF (IWS.EQ.4) CALL ZGQTNC(LTNATR)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWSTCL(ICOLOR)

*     / SET TONE COLOR IN 24BIT RGB /

      IF (IWS.EQ.1) CALL ZMSTCL(ICOLOR)
      IF (IWS.EQ.2) CALL ZMSTCL(ICOLOR)
      IF (IWS.EQ.3) CALL Z1STCL(ICOLOR)
      IF (IWS.EQ.4) CALL ZGSTCL(ICOLOR)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWGTON(NP,WPX,WPY,ITPAT)

*     / HARD FILL /

      IF (IWS.EQ.1) CALL ZMGTON(NP,WPX,WPY,ITPAT)
      IF (IWS.EQ.2) CALL ZMGTON(NP,WPX,WPY,ITPAT)
      IF (IWS.EQ.3) CALL Z1GTON(NP,WPX,WPY,ITPAT)
      IF (IWS.EQ.4) CALL ZGGTON(NP,WPX,WPY,ITPAT)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWSROT(IWTROT)

*     / SET FRAME ROTATION FLAG /

      IF (IWS.EQ.1) CALL ZMSROT(IWTROT)
      IF (IWS.EQ.2) CALL ZMSROT(IWTROT)
      IF (IWS.EQ.3) CALL Z1SROT(IWTROT)
      IF (IWS.EQ.4) CALL ZGSROT(IWTROT)

      RETURN
*-----------------------------------------------------------------------
*     IMAGE
*-----------------------------------------------------------------------
      ENTRY SWQIMC(LIMATR)

*     / INQUIRE BIT IMAGE CAPABILITY /

      IF (IWS.EQ.1) CALL ZMQIMC(LIMATR)
      IF (IWS.EQ.2) CALL ZMQIMC(LIMATR)
      IF (IWS.EQ.3) CALL Z1QIMC(LIMATR)
      IF (IWS.EQ.4) CALL ZGQIMC(LIMATR)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWIOPN(IWX,IWY,IMW,IMH)

*     / OPEN IMAGE /
*      IF (.NOT. LOPEN)
*     +   CALL MSGDMP('E', 'SWIOPN', CNOPN)
      IF (IWS.EQ.1) CALL ZMIOPN(IWX, IWY, IMW, IMH)
      IF (IWS.EQ.2) CALL ZMIOPN(IWX, IWY, IMW, IMH)
      IF (IWS.EQ.3) THEN
        CALL Z1CLIP(WX1, WY1, WX2, WY2, WX3, WY3, WX4, WY4)
        CALL Z1IOPN(IWX, IWY, IMW, IMH)
      ENDIF
      IF (IWS.EQ.4) CALL ZGIOPN(IWX, IWY, IMW, IMH)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWIDAT(IMAGE, NLEN)

*     / IMAGE DATA /
      IF (IWS.EQ.1) CALL ZMIDAT(IMAGE, NLEN)
      IF (IWS.EQ.2) CALL ZMIDAT(IMAGE, NLEN)
      IF (IWS.EQ.3) CALL Z1IDAT(IMAGE, NLEN)
      IF (IWS.EQ.4) CALL ZGIDAT(IMAGE, NLEN)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWICLR(IMAGE, NLEN)

*     / IMAGE DATA (FULL COLOR) /
      IF (IWS.EQ.1) CALL ZMICLR(IMAGE, NLEN)
      IF (IWS.EQ.2) CALL ZMICLR(IMAGE, NLEN)
      IF (IWS.EQ.3) CALL Z1ICLR(IMAGE, NLEN)
      IF (IWS.EQ.4) CALL ZGICLR(IMAGE, NLEN)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWICLS

*     / IMAGE CLOSE /

      IF (IWS.EQ.1) CALL ZMICLS
      IF (IWS.EQ.2) CALL ZMICLS
      IF (IWS.EQ.3) CALL Z1ICLS
      IF (IWS.EQ.4) CALL ZGICLS

      RETURN
*-----------------------------------------------------------------------
*     MOUSE
*-----------------------------------------------------------------------
      ENTRY SWQPTC(LPTATR)

*     / INQUIRE MOUSE POINT CAPABILITY /

      IF (IWS.EQ.1) CALL ZMQPTC(LPTATR)
      IF (IWS.EQ.2) CALL ZMQPTC(LPTATR)
      IF (IWS.EQ.3) CALL Z1QPTC(LPTATR)
      IF (IWS.EQ.4) CALL ZGQPTC(LPTATR)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWQPNT(WX,WY,MB)

*     / INQUIRE POSITION OF POINTER /

      IF (IWS.EQ.1) CALL ZMQPNT(WX,WY,MB)
      IF (IWS.EQ.2) CALL ZMQPNT(WX,WY,MB)
      IF (IWS.EQ.3) CALL Z1QPNT(WX,WY,MB)
      IF (IWS.EQ.4) CALL ZGQPNT(WX,WY,MB)

      RETURN
*-----------------------------------------------------------------------
*     TRANSFORMATION
*-----------------------------------------------------------------------
      ENTRY SWFINT(WX, WY, IWX, IWY)

*     / REAL TO INT /

      IF (IWS.EQ.1) CALL ZMFINT(WX, WY, IWX, IWY)
      IF (IWS.EQ.2) CALL ZMFINT(WX, WY, IWX, IWY)
      IF (IWS.EQ.3) CALL Z1FINT(WX, WY, IWX, IWY)
      IF (IWS.EQ.4) CALL ZGFINT(WX, WY, IWX, IWY)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWIINT(IWX, IWY, WX, WY)

*     / INT TO REAL /

      IF (IWS.EQ.1) CALL ZMIINT(IWX, IWY, WX, WY)
      IF (IWS.EQ.2) CALL ZMIINT(IWX, IWY, WX, WY)
      IF (IWS.EQ.3) CALL Z1IINT(IWX, IWY, WX, WY)
      IF (IWS.EQ.4) CALL ZGIINT(IWX, IWY, WX, WY)

      RETURN
*-----------------------------------------------------------------------
      ENTRY SWQRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)

*     / INQUIRE WORKSTATION RECTANGLE /

      IF (IWS.EQ.1) CALL ZMQRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)
      IF (IWS.EQ.2) CALL ZMQRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)
      IF (IWS.EQ.3) CALL Z1QRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)
      IF (IWS.EQ.4) CALL ZGQRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)

      RETURN

*-----------------------------------------------------------------------
      ENTRY SWCLCH()

*     / CHANGE COLORMAP IMMIDIATELY /

      CALL SWIGET('ICLRMAP', ICLRMP)
      CALL SWQCMF(ICLRMP,CMAP)
      CALL SWCSET('CLRMAP',CMAP)
      CALL SWQFNM('CLRMAP ', CLRMAP)
      IF (CLRMAP.EQ.' ') THEN
        CALL MSGDMP('E','SWDOPN','COLORMAP FILE DOES NOT EXISIT.')
      END IF

      IF (IWS.EQ.1) CALL ZMCLINI(CLRMAP)
      IF (IWS.EQ.2) CALL ZMCLINI(CLRMAP)
      IF (IWS.EQ.3) CALL Z1CLINI(CLRMAP)
      IF (IWS.EQ.4) CALL ZGCLINI(CLRMAP,LFGBG)

      RETURN

      END
